@@ -35,8 +35,6 @@
 #define ID_PREF_GROUP_GENERAL			"General"
 #define ID_PREF_GEN_TOOLTIPS			"ToolTips"
 #define PREF_GEN_TOOLTIPS					true
-#define ID_PREF_GEN_CDMOUNTPT			"CDMountPoint"
-#define PREF_GEN_CDMOUNTPT				"/mnt"
 
 #define ID_PREF_GROUP_SEARCH		"Search"
 #define ID_PREF_SEA_BYWORDS			"Bywords"
