@@ -137,6 +137,8 @@ KHeiseView::KHeiseView(QWidget *parent, const char *name): QWidget(parent, name)
 	vbox->activate();
 
 	connect(articleview, SIGNAL(currentChanged(QListViewItem *)), this, SLOT(currentChangedSlot(QListViewItem *)));
+	connect(articleview, SIGNAL(doubleClicked(QListViewItem *)), this, SLOT(executedSlot(QListViewItem *)));
+	connect(articleview, SIGNAL(returnPressed(QListViewItem *)), this, SLOT(executedSlot(QListViewItem *)));
 }
 
 
@@ -228,3 +230,10 @@ void KHeiseView::currentChangedSlot(QListViewItem *item)
 		links->clear();
 	}
 }
+
+
+void KHeiseView::executedSlot(QListViewItem *item)
+{
+	if (item)
+		viewaction->activate();
+}
