@@ -47,7 +47,7 @@ int main(int argc, char *argv[])
 		VERSION, description, KAboutData::License_GPL,
 		"(C) 2002 Oliver Gantz",
 		0,
-		"http://www.tu-bs.de/~y0000441/kheisereg/index.html",
+		"http://www.gantz-edv.de/kheisereg/index.html",
 		"Oliver.Gantz@ePost.de");
 	
 	aboutData.addAuthor("Oliver Gantz", 0, "Oliver.Gantz@ePost.de");
