@@ -33,9 +33,9 @@
 #include <qfile.h>
 
 
-#define REG_MAGAZINE_NONE 0x00
-#define REG_MAGAZINE_CT   0x01
-#define REG_MAGAZINE_IX   0x02
+#define REG_MAGAZINE_NONE    0x00
+#define REG_MAGAZINE_CT      0x01
+#define REG_MAGAZINE_IX      0x02
 
 
 #define REG_LINE_SIZE				512
@@ -170,11 +170,11 @@ public:
 	 * Returns the content of a certain entry line.
 	 *
 	 * The trailing <CR><LF> linebreak sequence is omitted and the charater set is tranformed
-	 * to latin1.
+	 * to unicode.
 	 *
 	 * @param num The line number to refer to (must be between 0 and 8).
 	 */
-	QCString lineStr(int num) const;
+	QString lineStr(int num) const;
 
 	const char *title() const;
 	const char *subTitle() const;
@@ -187,7 +187,7 @@ public:
 	const char *links() const;
 	const char *bywords() const;
 
-	bool verify() const;
+	int verify() const;
 
 private:
 	char m_lines[9][REG_LINE_SIZE];
@@ -276,6 +276,7 @@ public:
 	int firstEdition(unsigned char mag) const;
 	int lastEdition(unsigned char mag) const;
 	int articles(unsigned char mag) const;
+	int errorPos() const;
 	
 	RegNumList editions(unsigned char mag) const;
 
@@ -290,20 +291,12 @@ private:
 	int ix_articles;
 	RegNumList ct_editions;
 	RegNumList ix_editions;
+	int error_pos;
 };
 
 
-inline int RegFile::editionCount(unsigned char mag) const
-{	return (mag & REG_MAGAZINE_CT) ? ct_editions.size() : ix_editions.size(); }
-
-inline int RegFile::lastEdition(unsigned char mag) const
-{	return (mag & REG_MAGAZINE_CT) ? ct_last_ed : ix_last_ed; }
-
-inline int RegFile::articles(unsigned char mag) const
-{	return (mag & REG_MAGAZINE_CT) ? ct_articles : ix_articles; }
-
-inline RegNumList RegFile::editions(unsigned char mag) const
-{	return (mag & REG_MAGAZINE_CT) ? ct_editions : ix_editions; }
+inline int RegFile::errorPos() const
+{	return error_pos; }
 
 
 
